# mstool

[mstool](https://mstool.readthedocs.io/en/latest/#) is a multiscale simulation tool that converts a coarse-grained structure into an all-atom structure. It requires minimal user input (mapping and isomeric information of molecules). For more details, please check out the [paper](https://pubs.acs.org/doi/10.1021/acs.jpcb.3c05593) and [documentation](https://mstool.readthedocs.io/en/latest/#).
